@@ -22,7 +22,7 @@ def send_log(alert_id, context, payload=None):
     import traceback
     import requests
     base_url = __get_base_url(context['env'])
-    req_url = '{}/alerting/log/{alert_id}'.format(base_url, alert_id)
+    req_url = '{}/alerting/log/{}'.format(base_url, alert_id)
 
     req_body = {
         "trackback_log": traceback.format_exc(),
